@@ -36,7 +36,9 @@ class Requester(object):
                                 "allocations",
                                 "deployment",
                                 "deployments",
-                                "acl"
+                                "acl",
+                                "client",
+                                "node"
                              ]
         # split 0 -> Api Version
         # split 1 -> Working Endpoint
@@ -158,5 +160,5 @@ class Requester(object):
             else:
                 raise nomad.api.exceptions.BaseNomadException(response)
 
-        except requests.RequestException:
-            raise nomad.api.exceptions.BaseNomadException(response)
+        except requests.RequestException as error:
+            raise nomad.api.exceptions.BaseNomadException(error)
